@@ -1,5 +1,5 @@
-# $Revision: 2.14 $
-# $Id: ISBN.pm,v 2.14 2007/10/02 08:13:37 comdog Exp $
+# $Revision: 2.16 $
+# $Id: ISBN.pm,v 2.16 2008/08/09 04:29:55 comdog Exp $
 package Business::ISBN;
 use strict;
 
@@ -12,24 +12,26 @@ Business::ISBN - work with International Standard Book Numbers
 	use Business::ISBN;
 
 	# 10 digit ISBNs
-	$isbn_object = Business::ISBN->new('1565922573');
-	$isbn_object = Business::ISBN->new('1-56592-257-3');
+	$isbn10 = Business::ISBN->new('1565922573');
+	$isbn10 = Business::ISBN->new('1-56592-257-3');
 
 	# 13 digit ISBNs
-	$isbn_object = Business::ISBN->new('978-0-596-52724-2');
+	$isbn13 = Business::ISBN->new('978-0-596-52724-2');
 
 	# convert
-	$isbn10 = $isbn->as_isbn10;    # for the 978 prefixes
+	$isbn10 = $isbn13->as_isbn10;    # for the 978 prefixes
 	
 	$isbn13 = $isbn10->as_isbn13;
 
-
+	# maybe you don't care what it is as long as everything works
+	$isbn = Business::ISBN->new( $ARGV[0] );
+	
 	#print the ISBN with hyphens at usual positions 
-	print $isbn_object->as_string;
+	print $isbn->as_string;
 
 	#print the ISBN with hyphens at specified positions.
 	#this not does affect the default positions
-	print $isbn_object->as_string([]);
+	print $isbn->as_string([]);
 
 	#print the group code or publisher code
 	print $isbn->group_code;
@@ -37,14 +39,14 @@ Business::ISBN - work with International Standard Book Numbers
 	print $isbn->publisher_code;
 
 	#check to see if the ISBN is valid
-	$isbn_object->is_valid;
+	$isbn->is_valid;
 
 	#fix the ISBN checksum.  BEWARE:  the error might not be
 	#in the checksum!
-	$isbn_object->fix_checksum;
+	$isbn->fix_checksum;
 
 	# create an EAN13 barcode in PNG format
-	$isbn_object->png_barcode;
+	$isbn->png_barcode;
 
 =head1 DESCRIPTION
 
@@ -70,7 +72,7 @@ use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS $debug %group_data
 use Carp qw(carp croak cluck);
 use base qw(Exporter);
 
-use Business::ISBN::Data 1.15; # now a separate module
+use Business::ISBN::Data 20081208; # now a separate module
 # ugh, hack
 *group_data = *Business::ISBN::country_data;
 sub _group_data { $group_data{ $_[1] } }
@@ -108,7 +110,7 @@ BEGIN {
 		);
 	};
 	
-$VERSION = "2.03";
+$VERSION = "2.05";
 
 sub INVALID_PREFIX         () { -4 };
 sub INVALID_GROUP_CODE     () { -2 };
@@ -577,7 +579,7 @@ sub png_barcode
 		}
 
 	my $image = GD::Barcode::EAN13->new($ean)->plot->png;
-
+	
 	return $image;
 	}
 	
@@ -813,13 +815,9 @@ __END__
 
 =head1 SOURCE AVAILABILITY
 
-This source is part of a SourceForge project which always has the
-latest sources in CVS, as well as all of the previous releases.
+This source is in Github:
 
-	http://sourceforge.net/projects/perl-isbn/
-
-If, for some reason, I disappear from the world, one of the other
-members of the project can shepherd this module appropriately.
+    http://github.com/briandfoy/business--isbn/tree/master
 
 =head1 AUTHOR
 
@@ -827,7 +825,7 @@ brian d foy C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2001-2007, brian d foy, All Rights Reserved.
+Copyright (c) 2001-2009, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
